/*
 * Copyright (C) 2006 Johan Maasing johan at zoom.nu Licensed under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law
 * or agreed to in writing, software distributed under the License is
 * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package nu.zoom.catonine.desktop.about;

import java.awt.BorderLayout;

import javax.swing.JEditorPane;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.event.HyperlinkEvent;
import javax.swing.event.HyperlinkListener;

import nu.zoom.gal.error.ErrorReporter;
import nu.zoom.ui.Resources;

/**
 * Swing component to display the svansprogram about information.
 * 
 * @author "Johan Maasing" &lt;johan@zoom.nu&gt;
 */
class AboutComponent extends JPanel {

	private static final long serialVersionUID = 1L;
	private final Resources messages;
	private final ErrorReporter errorReporter;
	private final String version;

	AboutComponent(final ErrorReporter errorReporter, final Resources messages,
			final String version) {
		super(new BorderLayout());
		this.messages = messages;
		this.errorReporter = errorReporter;
		this.version = version;
	}

	void init() {
		try {
			add(new JLabel(messages.getIcon("nu.zoom.catonine.about.image")),
					BorderLayout.WEST);
			JEditorPane aboutPane = new JEditorPane("text/html",
					messages.format("nu.zoom.catonine.about.text1",
							this.version));
			aboutPane.setEditable(false);
			aboutPane.addHyperlinkListener(new HyperlinkListener() {

				@Override
				public void hyperlinkUpdate(HyperlinkEvent e) {
					if (e.getEventType() == HyperlinkEvent.EventType.ACTIVATED) {
						openBrowser(e.getURL().toExternalForm());
					}
				}

			});
			add(aboutPane, BorderLayout.CENTER);
		} catch (Resources.ResourceNotFoundException resourceNotFoundException) {
		}
	}

	public void openBrowser(final String uriString) {
		if (java.awt.Desktop.isDesktopSupported()) {

			java.awt.Desktop desktop = java.awt.Desktop
					.getDesktop();

			if (desktop.isSupported(java.awt.Desktop.Action.BROWSE)) {
				try {
					java.net.URI uri = new java.net.URI(uriString);
					desktop.browse(uri);
				} catch (Exception exc) {
					errorReporter.reportError(exc);
				}
			}
		}
	}
}
